//--------------------------------------------------------------
// File     : xmc2go_ub_system.c
// Datum    : 16.05.2014
// Version  : 1.1 (angepasst fuer uPlay)
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : XMC1100-0064 (XMC2GO)
// IDE      : KEIL uVision 5.10
// ARMCC    : 5.04
// Module   : XMC1100
// Funktion : System-Funktionen
//--------------------------------------------------------------


/*******************************************************************************
 Copyright (c) 2013, Infineon Technologies AG                                 **
 All rights reserved.                                                         **
                                                                              **
 Redistribution and use in source and binary forms, with or without           **
 modification,are permitted provided that the following conditions are met:   **
                                                                              **
 *Redistributions of source code must retain the above copyright notice,      **
 this list of conditions and the following disclaimer.                        **
 *Redistributions in binary form must reproduce the above copyright notice,   **
 this list of conditions and the following disclaimer in the documentation    **
 and/or other materials provided with the distribution.                       **
 *Neither the name of the copyright holders nor the names of its contributors **
 may be used to endorse or promote products derived from this software without**
 specific prior written permission.                                           **
                                                                              **
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"  **
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE    **
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE   **
 ARE  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE   **
 LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR         **
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF         **
 SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS    **
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN      **
 CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)       **
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE   **
 POSSIBILITY OF SUCH DAMAGE.                                                  **
                                                                              **
 To improve the quality of the software, users are encouraged to share        **
 modifications, enhancements or bug fixes with Infineon Technologies AG       **
 dave@infineon.com).                                                          **
*******************************************************************************/



//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "xmc2go_ub_system.h"
#include "xmc2go_ub_led.h"
#include "xmc2go_ub_nokia5110.h"

//--------------------------------------------------------------
uint8_t systic_enable;
uint32_t systic_cnt;
uint8_t led2_enable;
uint32_t led2_cnt_ms;
uint8_t display_enable;
uint8_t break_btn;
uint16_t basic_cnt_ms;

//--------------------------------------------------------------
// Init vom XMC2GO-System
//--------------------------------------------------------------
void XMC2GO_System_Init(void)
{
  systic_enable=0;
  systic_cnt=0;
  led2_cnt_ms=0;
  display_enable=0;
  break_btn=0;
	
  // Clock configuration
  SCU_GENERAL->PASSWD = 0x000000C0UL; // disable bit protection
  SCU_CLK->CLKCR = 0x3FF00400UL; // MCLK = 8MHz, PCLK = 8MHz
  while((SCU_CLK->CLKCR & SCU_CLK_CLKCR_VDDC2LOW_Msk));
  SCU_GENERAL->PASSWD = 0x000000C3UL; // enable bit protection
  SystemCoreClockUpdate();	
}


//--------------------------------------------------------------
// starten vom Systic
//--------------------------------------------------------------
void XMC2GO_Systic_Start(void)
{	
  SysTick_Config(SystemCoreClock / TICKS_PER_SECOND);	
  systic_enable=1;
}


//--------------------------------------------------------------
// Pause per Systic (in ms)
//--------------------------------------------------------------
void XMC2GO_Systic_Pause_ms(uint32_t ms)
{
  if(systic_enable==0) return;
	
  systic_cnt=0;
  while(systic_cnt<ms);
}

//--------------------------------------------------------------
// ruecksetzen vom Basic-Timer
//--------------------------------------------------------------
void XMC2GO_Systic_ClrTic(void)
{
  basic_cnt_ms=0;
}


//--------------------------------------------------------------
// auslesen vom Basic-Timer
//--------------------------------------------------------------
uint16_t XMC2GO_Systic_GetTic(void)
{
  return(basic_cnt_ms);
}

//--------------------------------------------------------------
// Mode der LED2 einstellen
//--------------------------------------------------------------
void XMC2GO_Systic_enableLED2(uint8_t mode)
{
  if(mode==0) {
    led2_enable=0;
    XMC2GO_Led_Off(LED2);
  }
  else {
    led2_enable=1;
  }		
}

//--------------------------------------------------------------
// Display aktivieren
//--------------------------------------------------------------
void XMC2GO_Systic_aktivateLCD(void)
{
  display_enable=1;
}

//--------------------------------------------------------------
// Status vom Break-Button an P0.6 auslesen
//--------------------------------------------------------------
uint8_t XMC2GO_Systic_checkBreakBtn(void)
{
  return(break_btn);
}

//--------------------------------------------------------------
// ISR vom Systic
//--------------------------------------------------------------
void SysTick_Handler(void)
{
  static uint32_t led1_cnt_ms=0,led1_mode=0;
  static uint32_t led2_cnt_ms=0,led2_mode=0;
  static uint32_t lcd_cnt_ms=0;	
	
  systic_cnt+=MS_PER_TIC;
  basic_cnt_ms+=MS_PER_TIC;
	
  //-------------------------------
  // LED1 (Heartbeat)
  //-------------------------------
  led1_cnt_ms+=MS_PER_TIC;
  if(led1_mode==0) {
    if(led1_cnt_ms>HEARTBEAT_WAIT_MS) {
      led1_cnt_ms=0;
      led1_mode=1;
      XMC2GO_Led_On(LED1);
    }
  }
  else {
    if(led1_cnt_ms>HEARTBEAT_BLINK_MS) {
      led1_cnt_ms=0;
      led1_mode=0;
      XMC2GO_Led_Off(LED1);			
    }
  }
	
  //-------------------------------
  // LED2 (uBasic running)
  //-------------------------------	
  if(led2_enable!=0) {
    led2_cnt_ms+=MS_PER_TIC;
    if(led2_mode==0) {
      if(led2_cnt_ms>LED2_WAIT_MS) {
        led2_cnt_ms=0;
        led2_mode=1;
        XMC2GO_Led_On(LED2);
      }
    }
    else {
      if(led2_cnt_ms>LED2_BLINK_MS) {
        led2_cnt_ms=0;
        led2_mode=0;
        XMC2GO_Led_Off(LED2);			
      }
    }
  }
	
  //-------------------------------
  // Display (refresh)
  //-------------------------------	
  if(display_enable!=0) {
    lcd_cnt_ms+=MS_PER_TIC;
    if(lcd_cnt_ms>LCD_REFRESH_MS) {
      lcd_cnt_ms=0;
      break_btn=XMC2GO_LCD_Refresh();			
    }
  }
}
