//--------------------------------------------------------------
// File     : xmc2go_ub_uart.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __XMC2GO_UB_UART_H
#define __XMC2GO_UB_UART_H


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include <stdint.h>
#include <xmc1100.h>
#include "gpio.h"


// UART baud rate constants for 115.2kbps @ MCLK=8MHz
#define UART_FDR_STEP 590UL
#define UART_BRG_PDIV 3UL
#define UART_BRG_DCTQ 9UL
#define UART_BRG_PCTQ 0UL


//--------------------------------------------------------------
// Endekennung beim Senden
//--------------------------------------------------------------
typedef enum {
  NONE = 0,  // keine Endekennung
  LFCR,      // LineFeed + CarriageReturn (0x0A,0x0D)
  CRLF,      // CarriageReturn + LineFeed (0x0D,0x0A)
  LF,        // nur LineFeed (0x0A)
  CR         // nur CarriageReturn (0x0D)
}UART_LASTBYTE_t;


//--------------------------------------------------------------
// Status beim Empfangen
//--------------------------------------------------------------
typedef enum {
  RX_EMPTY = 0,  // nichts empfangen
  RX_READY,      // es steht was im Empfangspuffer
  RX_FULL        // RX-Puffer ist voll
}UART_RXSTATUS_t;


//--------------------------------------------------------------
// Defines fuer das Empfangen
//--------------------------------------------------------------
#define  RX_BUF_SIZE   100   // Grsse vom RX-Puffer in Bytes
#define  RX_FIRST_CHR  0x20  // erstes erlaubte Zeichen (Ascii-Wert)
#define  RX_LAST_CHR   0x7E  // letztes erlaubt Zeichen (Ascii-Wert)
#define  RX_END_CHR    0x0D  // Endekennung (Ascii-Wert)


//--------------------------------------------------------------
// Struktur fr UART_RX
//--------------------------------------------------------------
typedef struct {
  char rx_buffer[RX_BUF_SIZE]; // RX-Puffer
  uint8_t wr_ptr;              // Schreib Pointer
  UART_RXSTATUS_t status;      // RX-Status
}UART_RX_t;



//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
void XMC2GO_Uart_Init(void);
void XMC2GO_Uart_SendByte(uint8_t wert);
void XMC2GO_Uart_SendString(char *ptr, UART_LASTBYTE_t end_cmd);
UART_RXSTATUS_t XMC2GO_Uart_ReceiveString(char *ptr);


//--------------------------------------------------------------
#endif // __XMC2GO_UB_uart_H
